==> igniteui-react-inputs-18.2.0.tgz: package/esm5/lib/XIconBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { XComponentBridge } from "./XComponentBridge";
import { enumGetBox, markType } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
import { SvgIconRegistry } from "igniteui-react-core";
import { stringStartsWith } from "igniteui-react-core";
import { trimStart } from "igniteui-react-core";
/**
 * @hidden
 */
var XIconBridge = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(XIconBridge, _super);
    function XIconBridge(a) {
        var _this = _super.call(this, a) || this;
        _this.u = "default";
        _this.v = null;
        return _this;
    }
    XIconBridge.prototype.getValue = function (a, b) {
        var c = a;
        switch (b) {
            case 16: return this.v;
            case 15: return this.u;
            case 18: return enumGetBox(BaseControlTheme_$type, c.i);
            case 44: return c.al;
            case 45: return c.am;
            case 46: return c.an;
            case 47: return c.ak;
            case 48: return c.ao;
            case 49: return c.ag;
        }
        return _super.prototype.getValue.call(this, a, b);
    };
    XIconBridge.prototype.setValue = function (a, b, c) {
        _super.prototype.setValue.call(this, a, b, c);
        var d = a;
        switch (b) {
            case 15:
                {
                    this.u = c;
                    var e = SvgIconRegistry.instance.getSvgPathString(this.u, this.v);
                    if (e != null) {
                        if (stringStartsWith(trimStart(e, ' ', '\n', '\r', '\t'), "<svg")) {
                            d.svg = e;
                        }
                        else {
                            d.svgPath = e;
                        }
                    }
                }
                break;
            case 16:
                {
                    this.v = c;
                    var f = SvgIconRegistry.instance.getSvgPathString(this.u, this.v);
                    if (f != null) {
                        if (stringStartsWith(trimStart(f, ' ', '\n', '\r', '\t'), "<svg")) {
                            d.svg = f;
                        }
                        else {
                            d.svgPath = f;
                        }
                    }
                }
                break;
            case 44:
                d.al = c;
                break;
            case 45:
                d.am = c;
                break;
            case 46:
                d.an = c;
                break;
            case 47:
                d.ak = c;
                break;
            case 48:
                d.ao = c;
                break;
            case 49:
                d.ag = c;
                break;
        }
    };
    XIconBridge.$t = markType(XIconBridge, 'XIconBridge', XComponentBridge.$);
    return XIconBridge;
}(XComponentBridge));
export { XIconBridge };

==> igniteui-react-inputs-18.6.1.tgz: package/esm5/lib/XIconBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { XComponentBridge } from "./XComponentBridge";
import { enumGetBox, markType } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
import { SvgIconRegistry } from "igniteui-react-core";
import { stringStartsWith } from "igniteui-react-core";
import { trimStart } from "igniteui-react-core";
/**
 * @hidden
 */
var XIconBridge = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(XIconBridge, _super);
    function XIconBridge(a) {
        var _this = _super.call(this, a) || this;
        _this.u = "default";
        _this.v = null;
        return _this;
    }
    XIconBridge.prototype.getValue = function (a, b) {
        var c = a;
        switch (b) {
            case 16: return this.v;
            case 15: return this.u;
            case 18: return enumGetBox(BaseControlTheme_$type, c.k);
            case 44: return c.an;
            case 45: return c.ao;
            case 46: return c.ap;
            case 47: return c.am;
            case 48: return c.aq;
            case 49: return c.ai;
            case 62: return c.e;
            case 63: return c.f;
            case 64: return c.al;
        }
        return _super.prototype.getValue.call(this, a, b);
    };
    XIconBridge.prototype.setValue = function (a, b, c) {
        _super.prototype.setValue.call(this, a, b, c);
        var d = a;
        switch (b) {
            case 15:
                {
                    this.u = c;
                    this.w(d);
                }
                break;
            case 16:
                {
                    this.v = c;
                    this.w(d);
                }
                break;
            case 44:
                d.an = c;
                break;
            case 45:
                d.ao = c;
                break;
            case 46:
                d.ap = c;
                break;
            case 47:
                d.am = c;
                break;
            case 48:
                d.aq = c;
                break;
            case 49:
                d.ai = c;
                break;
            case 62:
                d.e = c;
                break;
            case 63:
                d.f = c;
                break;
            case 64:
                d.al = c;
                break;
        }
    };
    XIconBridge.prototype.getTargetForProperty = function (a, b) {
        switch (a) {
            case 24: return b;
        }
        return _super.prototype.getTargetForProperty.call(this, a, b);
    };
    XIconBridge.prototype.w = function (a) {
        a.svg = null;
        a.svgPath = null;
        a.b = null;
        var b = SvgIconRegistry.instance.getSvgPathString(this.u, this.v);
        if (b != null) {
            if (stringStartsWith(trimStart(b, ' ', '\n', '\r', '\t'), "<svg")) {
                a.svg = b;
            }
            else {
                a.svgPath = b;
            }
            return;
        }
        var c = SvgIconRegistry.instance.getSvgPathsString(this.u, this.v);
        if (c != null) {
            a.b = c;
            return;
        }
        var d = SvgIconRegistry.instance.getDataURLString(this.u, this.v);
        if (d != null) {
            a.a7 = d;
            return;
        }
    };
    XIconBridge.$t = markType(XIconBridge, 'XIconBridge', XComponentBridge.$);
    return XIconBridge;
}(XComponentBridge));
export { XIconBridge };
